@@ -13,8 +13,6 @@ def before_all(project_path):
     """
     check if target directory exist, if not - create this directory with screenshots folder in.
     """
-    # Get project path
-    infra_project_path = dirname(dirname(__file__))
 
     # Store the project user directory param in pytest global variables
     pytest.user_dir = project_path
